#include <iostream>
#include <iomanip>
#include "crc.h"

/* TO COMPILE: 
*
* g++ calc_crc.cpp crc.cpp -o calc_crc
*
* TO TEST:
* ./calc_crc
*
*/

int main(int argc, char **argv){
    // uint8_t frame[6] = {0xEC, 0x04, 0x32, 0x62, 0x64};      // Example frame, for bind command
    uint8_t frame[6] = {0xEC, 0x04, 0x32, 0x75, 0x62};      // Example frame, for unbind command
    uint8_t frame_size = BIND_FRAME_SIZE;                   // Frame size for bind commands
    
    // uint8_t frame[7] = {0xEC, 0x05, 0x28, 0xEC, 0xC8, 0xEC};    // Example frame, for device info command
    // uint8_t frame_size = DEVICE_INFO_FRAME_SIZE;            // Frame size for device info command

    GENERIC_CRC8 crsf_crc(CRSF_CRC_POLY);
    uint8_t crc = crsf_crc.calc(&frame[CRSF_FRAME_NOT_COUNTED_BYTES], frame_size - 1, 0);
    
    frame[5] = crc;     // Set crc for bind command
    // frame[6] = crc;     // Set crc for device info command

    std::cout << "Calculated CRC(int): " << static_cast<int>(crc) << std::endl;
    std::cout << "Calculated CRC(hex): 0x"
              << std::setfill('0') << std::setw(2) << std::hex << static_cast<int>(crc) << std::endl;
    std::cout << "Full packet:";
    for (auto byte : frame){
        std::cout << " 0x" << std::setfill('0') << std::setw(2) << std::hex << std::uppercase << static_cast<int>(byte);
    }
    std::cout << std::endl;
}