#!/bin/python3
import serial
import ctypes as ct
import os 
import subprocess

VOXL_PLATFORM = False
try:
	ret = subprocess.check_output(['voxl-platform'])
	VOXL_PLATFORM = True
except FileNotFoundError:
	VOXL_PLATFORM = False

# Detect if we are on a voxl2 or host computer
if VOXL_PLATFORM:
    import voxl_serial
    BASE_DIR = '/usr/share/modalai/voxl-elrs'
    host = "voxl2"
else:
    BASE_DIR = '/usr/share/modalai/voxl-elrs'
    host = "ubuntu"

uint8_t = ct.c_uint8
if host == "voxl2":
    dev = voxl_serial.VoxlSerialPort()
    dev.port = '/dev/tty-slpi-7'
    dev.baudrate = 420000
    dev.open()
else:
    # Automatically opens serial
    dev = serial.Serial("/dev/ttyUSB0",420000)
    
# Bind command 
data_out = (uint8_t * 6)()
data_out[0] = 0xEC  # ADDR -> RECEIVER
data_out[1] = 0x04  # LEN  -> 4 BYTES
data_out[2] = 0x32  # TYPE -> COMMAND
data_out[3] = 0x75  # COM1 -> 'u'
data_out[4] = 0x62  # COM2 -> 'b'
data_out[5] = 0x23  # CRC  -> 35

bytes_out = bytearray(data_out)
data = (uint8_t * 64)()

# Write command to UART port
# print(f'\nSending {len(data_out)} bytes: {list(data_out)}')
dev.write(bytes_out)
dev.close()